@@ -40,8 +40,15 @@ def build(folders, edit):
 @main.command()
 @click.argument('folders', nargs=-1, required=True)
 @click.option('--edit')
+@click.option('--fail-fast', is_flag=True, show_default=True,
+              help='Stop processing immediately when an error occurs')
+@click.option('--force-color/--disable-color', default=True,
+              help='Force ANSI colors on non-terminals, or turn it off '
+                   'always  [default: --force-color]')
 @click.option('--ignore-missing-schemas', flag_value='ignore_missing_schemas',
-              default=False)
-def lint(folders, edit, ignore_missing_schemas):
+              default=False, show_default=True,
+              help='Skip validation for resource definitions without a schema')
+def lint(folders, edit, fail_fast, force_color, ignore_missing_schemas):
     """Verify whether manifests built by kustomize are valid"""
-    lint_command.lint(folders, edit, ignore_missing_schemas)
+    lint_command.lint(
+        folders, edit, fail_fast, force_color, ignore_missing_schemas)
