@@ -4,15 +4,16 @@ Perform validation of manifest built by kustomize
 from ..binaries import realpath, shell
 
 
-def lint(folders, edit, ignore_missing_schemas):
+def lint(folders, edit, fail_fast, force_color, ignore_missing_schemas):
     """
     Verify whether manifests built by kustomize are valid
     """
     kustomize = realpath('kustomize')
     kubeval = realpath('kubeval')
     kubeval_options = ' '.join([
-        '--strict',
+        '--force-color' if force_color else '',
         '--ignore-missing-schemas' if ignore_missing_schemas else '',
+        '--strict',
     ])
 
     if edit:
@@ -21,6 +22,6 @@ def lint(folders, edit, ignore_missing_schemas):
     status = 0
     for folder in folders:
         command = f"{kustomize} build {folder} | {kubeval} {kubeval_options}"
-        status += shell(command).returncode
+        status += shell(command, fail=fail_fast).returncode
 
     raise SystemExit(status)
